@@ -274,7 +274,6 @@ def remove_symlink(symlink):
         os.unlink(symlink)
 
 
-
 def remove_symlinks(symlinks, raise_on_error=False):
     """Remove one or more symlinks.
 
@@ -510,7 +509,7 @@ def _get_win_folder_with_pywin32(csidl_name):
     # not return unicode strings when there is unicode data in the
     # path.
     try:
-        dir = str(dir) if PY3 else unicode(dir)
+        dir = str(dir) if PY3 else unicode(dir)  # noqa: F821
 
         # Downgrade to short path name if have highbit chars. See
         # <http://bugs.activestate.com/show_bug.cgi?id=85099>.
@@ -557,11 +556,11 @@ def _get_win_folder_with_ctypes(csidl_name):
 
 if system == "win32":
     try:
-        import win32com.shell
+        import win32com.shell  # noqa: F401
         _get_win_folder = _get_win_folder_with_pywin32
     except ImportError:
         try:
-            from ctypes import windll
+            from ctypes import windll  # noqa: F401
             _get_win_folder = _get_win_folder_with_ctypes
         except ImportError:
             _get_win_folder = _get_win_folder_from_registry
