@@ -145,8 +145,6 @@ Mixins
     EdgeAttributesManagement
     FaceAttributesManagement
 
-    VertexCoordinatesDescriptors
-
     VertexFilter
     EdgeFilter
     FaceFilter
@@ -163,8 +161,6 @@ Mixins
     EdgeHelpers
     FaceHelpers
 
-    MagicMethods
-
     VertexMappings
     EdgeMappings
     FaceMappings
