@@ -3,12 +3,10 @@ from __future__ import division
 from __future__ import print_function
 
 from .attributes import *  # noqa: F401 F403
-from .descriptors import *  # noqa: F401 F403
 from .filters import *  # noqa: F401 F403
 from .fromto import *  # noqa: F401 F403
 from .geometry import *  # noqa: F401 F403
 from .helpers import *  # noqa: F401 F403
-from .magic import *  # noqa: F401 F403
 from .mappings import *  # noqa: F401 F403
 
 __all__ = [name for name in dir() if not name.startswith('_')]
