@@ -3,9 +3,9 @@ from __future__ import absolute_import
 from __future__ import division
 
 from compas.datastructures.mesh.smoothing import mesh_smooth_area
-from compas.datastructures.mesh.operations import trimesh_collapse_edge
-from compas.datastructures.mesh.operations import trimesh_swap_edge
-from compas.datastructures.mesh.operations import trimesh_split_edge
+from compas.datastructures.mesh.core import trimesh_collapse_edge
+from compas.datastructures.mesh.core import trimesh_swap_edge
+from compas.datastructures.mesh.core import trimesh_split_edge
 
 
 __all__ = [
