@@ -4,10 +4,9 @@ from __future__ import print_function
 
 import compas
 
-from .hull import *
-
+from .hull import *  # noqa: F401 F403
 if not compas.IPY:
-    from .hull_numpy import *
+    from .hull_numpy import *  # noqa: F401 F403
 
 
 __all__ = [name for name in dir() if not name.startswith('_')]
