@@ -12,7 +12,6 @@ Solvers
     :toctree: generated/
     :nosignatures:
 
-    descent_numpy
     devo_numpy
     dr
     dr_numpy
@@ -107,7 +106,6 @@ from .fd import *  # noqa: F401 F403
 from .drx import *  # noqa: F401 F403
 from .dr import *  # noqa: F401 F403
 from .devo import *  # noqa: F401 F403
-from .descent import *  # noqa: F401 F403
 
 
 __all__ = [name for name in dir() if not name.startswith('_')]
