@@ -81,13 +81,6 @@ class Proxy(object):
         with Proxy('compas.numerical') as numerical:
             pass
 
-    Complete example demonstrating use of the force density method in the
-    numerical package to compute equilibrium of axial force networks.
-
-    .. code-block:: python
-
-        pass
-
     """
 
     def __init__(self, package=None, python=None, url='http://127.0.0.1', port=1753, service=None):
@@ -104,7 +97,7 @@ class Proxy(object):
         self.package = package
 
         self._implicitely_started_server = False
-        self._server = self.try_reconnect()
+        self._server = self._try_reconnect()
         if self._server is None:
             self._server = self.start_server()
             self._implicitely_started_server = True
@@ -161,14 +154,13 @@ class Proxy(object):
     def python(self, python):
         self._python = python
 
-    def try_reconnect(self):
+    def _try_reconnect(self):
         """Try and reconnect to an existing proxy server.
 
         Returns
         -------
         ServerProxy
             Instance of the proxy if reconnection succeeded, otherwise ``None``.
-
         """
         server = ServerProxy(self.address)
         try:
@@ -193,9 +185,14 @@ class Proxy(object):
             If the server providing the requested service cannot be reached after
             100 contact attempts (*pings*).
 
+        Examples
+        --------
+        >>> p = Proxy()
+        >>> p.stop_server()
+        >>> p.start_server()
+
         """
         env = compas._os.prepare_environment()
-
         # this part starts the server side of the RPC setup
         # it basically launches a subprocess
         # to start the default service
@@ -211,7 +208,6 @@ class Proxy(object):
                     self._process.StartInfo.EnvironmentVariables[name] = env[name]
                 else:
                     self._process.StartInfo.EnvironmentVariables.Add(name, env[name])
-
             self._process.StartInfo.UseShellExecute = False
             self._process.StartInfo.RedirectStandardOutput = True
             self._process.StartInfo.RedirectStandardError = True
@@ -221,14 +217,11 @@ class Proxy(object):
         else:
             args = [self.python, '-m', self.service, str(self._port)]
             self._process = Popen(args, stdout=PIPE, stderr=PIPE, env=env)
-
         # this starts the client side
         # it creates a proxy for the server
         # and tries to connect the proxy to the actual server
         server = ServerProxy(self.address)
-
         print("Starting a new proxy server...")
-
         success = False
         count = 100
         while count:
@@ -245,11 +238,16 @@ class Proxy(object):
             raise RPCServerError("The server is not available.")
         else:
             print("New proxy server started.")
-
         return server
 
     def stop_server(self):
         """Stop the remote server and terminate/kill the python process that was used to start it.
+
+        Examples
+        --------
+        >>> p = Proxy()
+        >>> p.stop_server()
+        >>> p.start_server()
         """
         print("Stopping the server proxy.")
         try:
@@ -266,7 +264,6 @@ class Proxy(object):
         """
         if not self._process:
             return
-
         try:
             self._process.terminate()
         except Exception:
@@ -283,9 +280,9 @@ class Proxy(object):
             self._function = getattr(self._server, name)
         except Exception:
             raise RPCServerError()
-        return self.proxy
+        return self._proxy
 
-    def proxy(self, *args, **kwargs):
+    def _proxy(self, *args, **kwargs):
         """Callable replacement for the requested functionality.
 
         Parameters
@@ -305,11 +302,9 @@ class Proxy(object):
         The `args` and `kwargs` have to be JSON-serialisable.
         This means that, currently, only native Python objects are supported.
         The returned results will also always be in the form of built-in Python objects.
-
         """
         idict = {'args': args, 'kwargs': kwargs}
         istring = json.dumps(idict, cls=DataEncoder)
-
         # it makes sense that there is a broken pipe error
         # because the process is not the one receiving the feedback
         # when there is a print statement on the server side
@@ -323,17 +318,12 @@ class Proxy(object):
             # if this goes wrong, it means a Fault error was generated by the server
             # no need to stop the server for this
             raise
-
         if not ostring:
             raise RPCServerError("No output was generated.")
-
         result = json.loads(ostring)
-
         if result['error']:
             raise RPCServerError(result['error'])
-
         self.profile = result['profile']
-
         return result['data']
 
 
